from pkg_resources import get_distribution, DistributionNotFound

try:
    __version__ = get_distribution("django-widget-tweaks").version
except DistributionNotFound:
    # package is not installed
    __version__ = None



import string
from django import forms
from django.forms import Form, CharField, SelectDateWidget, TextInput
from django.template import Template, Context


class MyForm(Form):
    """
    Test form. If you want to test rendering of a field,
    add it to this form and use one of 'render_...' functions
    from this module.
    """

    simple = CharField()
    with_attrs = CharField(widget=TextInput(attrs={"foo": "baz", "egg": "spam"}))
    with_cls = CharField(widget=TextInput(attrs={"class": "class0"}))
    date = forms.DateField(widget=SelectDateWidget(attrs={"egg": "spam"}))


def render_form(text, form=None, **context_args):
    """
    Renders template ``text`` with widget_tweaks library loaded
    and MyForm instance available in context as ``form``.
    """
    tpl = Template("{% load widget_tweaks %}" + text)
    context_args.update({"form": MyForm() if form is None else form})
    context = Context(context_args)
    return tpl.render(context)


def render_field(field, template_filter, params, *args, **kwargs):
    """
    Renders ``field`` of MyForm with filter ``template_filter`` applied.
    ``params`` are filter arguments.

    If you want to apply several filters (in a chain),
    pass extra ``template_filter`` and ``params`` as positional arguments.

    In order to use custom form, pass form instance as ``form``
    keyword argument.
    """
    filters = [(template_filter, params)]
    filters.extend(zip(args[::2], args[1::2]))
    filter_strings = ['|%s:"%s"' % (f[0], f[1]) for f in filters]
    render_field_str = "{{ form.%s%s }}" % (field, "".join(filter_strings))
    return render_form(render_field_str, **kwargs)


def render_field_from_tag(field, *attributes):
    """
    Renders MyForm's field ``field`` with attributes passed
    as positional arguments.
    """
    attr_strings = [" %s" % f for f in attributes]
    tpl = string.Template("{% render_field form.$field$attrs %}")
    render_field_str = tpl.substitute(field=field, attrs="".join(attr_strings))
    return render_form(render_field_str)



#!/usr/bin/env python
from setuptools import setup

setup(
    name="django-widget-tweaks",
    use_scm_version={"version_scheme": "post-release"},
    setup_requires=["setuptools_scm"],
    author="Mikhail Korobov",
    author_email="kmike84@gmail.com",
    url="https://github.com/jazzband/django-widget-tweaks",
    description="Tweak the form field rendering in templates, not in python-level form definitions.",
    long_description=open("README.rst").read() + "\n\n" + open("CHANGES.rst").read(),
    long_description_content_type="text/x-rst",
    license="MIT license",
    python_requires=">=3.7",
    requires=["django (>=2.2)"],
    packages=["widget_tweaks", "widget_tweaks.templatetags"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Framework :: Django",
        "Framework :: Django :: 2.2",
        "Framework :: Django :: 3.2",
        "Framework :: Django :: 4.0",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)
